#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/brasero/2.32/brasero-2.32.0.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------ Set Some Variables

soft='brasero'
softversion='2.32.0'
arch="i486"
cpu="i686"
packageversion="66.2"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.txz
rm -rf $dest

cd $src
# added git fix_crasher.patch
cat $buildir/fix_crasher.patch | patch -p1 --verbose
# added git fix_build_iso.patch
cat $buildir/fix_build_iso.patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --enable-nautilus=no \
  --enable-caches=no \
  --disable-schemas-compile

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null cd $dest

gzip -9 $dest/usr/man/man?/*.?

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README \
  $dest/usr/doc/$soft-$softversion

# Description file

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler------------------------------------------------------|
brasero: brasero - is a CD/DVD burning application
brasero:
brasero: Brasero is a application to burn CD/DVD for the Gnome Desktop. It is
brasero: designed to be as simple as possible and has some unique features to
brasero: enable users to create their discs easily and quickly.
brasero:
brasero:
brasero:
brasero:
brasero:
brasero:
EODESC

cat << "DOINST" > $dest/install/doinst.sh
if [ -x /usr/bin/glib-compile-schemas ]; then
 /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
 fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
